#
# spec file for package earlyoom
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# The tests are quite flaky in a VM
%bcond_with tests
%if ! 0%{?_fillupdir:1}
%global _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           earlyoom
Version:        1.8.2
Release:        1.2
Summary:        Early OOM Daemon for Linux
License:        MIT
Group:          System/Daemons
URL:            https://github.com/rfjakob/%{name}
Source0:        https://github.com/rfjakob/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.sysconfig
# pandoc MANPAGE.md -s -t man > earlyoom.1
Source2:        earlyoom.1
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(systemd)
Conflicts:      oomd
%if %{with tests}
BuildRequires:  go
%endif

%description
earlyoom checks the amount of available memory and free swap, and if both are
below critical level, it will kill the largest process (highest oom_score).

%prep
%autosetup -p1
sed -i 's|/default/|/sysconfig/|' earlyoom.service.in
sed -e '/systemctl/d' -i Makefile

%build
CFLAGS='%{?build_cflags}%{!?build_cflags:%optflags} -DVERSION=\"%{version}\" -std=gnu99'
CPPFLAGS='%{?build_cxxflags}%{!?build_cxxflags:%optflags}'
LDFLAGS="-lrt ${RPM_LD_FLAGS}"
%make_build CFLAGS="$CFLAGS" CPPFLAGS="$CPPFLAGS" PREFIX=%{_prefix}

%check
test %{SOURCE2} -nt README.md
%if %{with tests}
sed -i 's|stderrContains: "earlyoom v",|stderrContains: "earlyoom %{version}",|' testsuite_cli_test.go
%make_build test
%endif

%install
%make_install PREFIX=%{_prefix} SYSTEMDUNITDIR=%{_unitdir}
install -Dpm0644 %{SOURCE1} %{buildroot}%{_fillupdir}/sysconfig.%{name}
install -Dpm0644 %{SOURCE2} %{buildroot}%{_mandir}/man1/%{name}.1

mkdir -p %{buildroot}%{_sbindir}
ln -s service %{buildroot}%{_sbindir}/rc%{name}

%files
%license LICENSE
%doc MANPAGE.md README.md
%{_bindir}/%{name}
%{_unitdir}/%{name}.service
%exclude %{_sysconfdir}/default/%{name}
%{_fillupdir}/sysconfig.%{name}
%{_sbindir}/rc%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%pre
%{service_add_pre %{name}.service}

%post
%{fillup_only %{name}}
%{service_add_post %{name}.service}

%preun
%{service_del_preun %{name}.service}

%postun
%{service_del_postun %{name}.service}

%changelog
* Sun May 12 2024 Илья Индиго <ilya@ilya.top>
- Manual optimizations in spec-file.
- Updated to 1.8.2
  * Changed file earlyoom.1 (MANPAGE.md -s -t man > earlyoom.1).
  * https://github.com/rfjakob/earlyoom#changelog
  * Fixed crash with -p flag in config and IPAddressDeny syntax.
* Thu Apr 18 2024 David B <db@mail25.net>
- Removed -p flag from configuration (ineffective for systemd unit).
* Tue Apr 16 2024 Илья Индиго <ilya@ilya.top>
- Updated to 1.8
  * Changed file earlyoom.1 (MANPAGE.md -s -t man > earlyoom.1).
  * https://github.com/rfjakob/earlyoom#changelog
  * Introduce user mem total / meminfo_t.UserMemTotal and
    calculate MemAvailablePercent.
  * Added NO_COLOR support.
  * Fixed handling of processes with a zombie main thread.
  * Added --sort-by-rss. This will select a process to kill acc
    to the largest RSS instead of largest oom_score.
* Wed May 18 2022 Илья Индиго <ilya@ilya.top>
- Refreshed spec-file via spec-cleaner and manual optimizated.
  * Reduced to the standard github URL.
  * Added -p flag to all install commands.
- Updated file earlyoom.sysconfig with actual firefox process names.
- Updated to 1.7
  * Changed file earlyoom.1 (MANPAGE.md -s -t man > earlyoom.1).
  * https://github.com/rfjakob/earlyoom#changelog
  * Added -N flag to run a script every time a process is killed.
  * Added -g flag to kill whole process group.
  * Removed -i flag, it does not work properly on Linux kernels 5.9+.
  * Droped ambient capabilities on startup.
* Thu Nov 18 2021 Илья Индиго <ilya@ilya.top>
- Added GeckoMain in --prefer parameter. (firefox name process)
- Removed firefox and chromium in --prefer parameter. (irrelevant)
* Fri May  7 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Package pre-built earlyoom.1 as pandoc / haskell is not supported
  on all archs.
- Drop pandoc BuildRequires.
* Thu Dec  3 2020 Dan Čermák <dcermak@suse.com>
- New upstream release 1.6.2
  * Double-check memory situation before killing victim ([commit](https://github.com/rfjakob/earlyoom/commit/e34e0fcec5d9f60eb19a48a3ec2bab175818fdd8))
  * Never terminate ourselves ([#205](https://github.com/rfjakob/earlyoom/issues/205))
  * Dump buffer on /proc/meminfo conversion error ([#214](https://github.com/rfjakob/earlyoom/issues/214))
- Remove invalid Recommends of libnotify-tools (boo#1179537)
- disable tests
- add link from /sbin/rcearlyoom to /sbin/service
* Thu Sep 17 2020 Dan Čermák <dcermak@suse.com>
- Enable tests on x86_64 & ARM
- change reporting interval to never
- remove calls to systemctl in make install
- change LDFLAGS handling via env variables
* Thu Sep  3 2020 Franck Bui <fbui@suse.com>
- Drop dependency on insserv-compat
  The sysvinit script is not shipped so this dependency on this
  obsolete package is not needed and can be removed.
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.6.1:
  * Clean up dbus-send zombie processes
  * Skip processes with oom_score_adj=-1000
* Wed Jun 10 2020 Dan Čermák <dcermak@suse.com>
- New upstream release 1.6
  * 1.6, 2020-04-11
  * Replace old `notify-send` GUI notification logic with `dbus-send` /
    [systembus-notify](https://github.com/rfjakob/systembus-notify)
    ([#183](https://github.com/rfjakob/earlyoom/issues/183))
  * `-n`/`-N` now enables the new logic
  * You need to have
    [systembus-notify](https://github.com/rfjakob/systembus-notify) running
    in your GUI session for notifications for work
  * Handle `/proc` mounted with
    [hidepid](https://github.com/rfjakob/earlyoom/wiki/proc-hidepid)
    gracefully ([issue #184](https://github.com/rfjakob/earlyoom/issues/184))
  * v1.5, 2020-03-22
  * `-p`: set oom_score_adj to `-100` instead of `-1000`
    ([#170](https://github.com/rfjakob/earlyoom/issues/170))
  * Allow using **both** `-M` and `-m`, and `-S` and `-s`. The lower value
    (converted to percentages) will be used.
  * Set memory report interval in `earlyoom.default` to 1 hour instead of 1
    minute ([#177](https://github.com/rfjakob/earlyoom/issues/177))
* Thu Mar 19 2020 Fabian Vogt <fvogt@suse.com>
- earlyoom.sysconfig: Fix sddm, add kwin_wayland
* Wed Mar  4 2020 Илья Индиго <ilya@ilya.top>
- Add PREFIX=%%{_prefix} to %%make_build macro for correct ExecStart.
- Update to 1.4
  * https://github.com/rfjakob/earlyoom#changelog
  * Make victim selection logic 50%% faster by lazy-loading process
    attributes.
  * Log the user id uid of killed processes in addition to pid and
    name.
  * Color debug log in light grey.
  * Code clean-up
  * Use block-local variables where possible.
  * Introduce PATH_LEN to replace several hardcoded buffer
    lengths.
  * Expand testsuite (make test).
  * Run cppcheck when available.
  * Add unit-test benchmarks (make bench).
  * Drop root privileges in systemd unit file earlyoom.service.
  * Fix spurious testsuite failure on systems with a lot of RAM.
* Fri Feb 21 2020 Илья Индиго <ilya@ilya.top>
- Add "Web\ Content" before "firefox" in --prefer parameter.
- Manual optimizations in spec-file.
* Thu Feb 20 2020 opensuse@trummer.xyz
- include Falkon browser and mpv media player among
  the list of programs to terminate preferably
* Wed Feb 19 2020 opensuse.lietuviu.kalba@gmail.com
- Add -p option.
* Sat Jan 11 2020 opensuse.lietuviu.kalba@gmail.com
- Set lower critical values, add more programs into whitelist.
* Mon Jan  6 2020 opensuse.lietuviu.kalba@gmail.com
- Clean-up.
* Thu Jun  6 2019 Alexander Evseev <aevseev@gmail.com>
- First build. Version - 1.3
